.. Goodman Focus documentation master file, created by
   sphinx-quickstart on Fri Jun 21 15:15:24 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Goodman Focus' documentation!
========================================

.. image:: https://github.com/soar-telescope/goodman_focus/workflows/Goodman%20Focus/badge.svg
    :alt: Goodman Focus
.. image:: https://coveralls.io/repos/github/soar-telescope/goodman_focus/badge.svg?branch=master
    :target: https://coveralls.io/github/soar-telescope/goodman_focus?branch=master
.. image:: https://readthedocs.org/projects/goodman-focus/badge/?version=latest
    :target: https://goodman-focus.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://img.shields.io/pypi/v/goodman_focus.svg
    :target: https://pypi.org/project/goodman-focus/
    :alt: PyPI

Overview
========

This is a tool to obtain the best focus from a series of images obtained at
different focus values. It works for imaging and for spectroscopy.

This tool requires python `3.6` at least to work. It will not install with `3.5`.


.. toctree::
   :maxdepth: 2
   :caption: How to Install

   install


.. toctree::
   :maxdepth: 2
   :caption: How to Use it

   gettingdata
   usingit


.. toctree::
   :maxdepth: 2
   :caption: Contents:


.. toctree::
   :maxdepth: 2
   :caption: About

   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
